@@ -1,14 +1,12 @@
 use strict;
 use warnings;
 package Dist::Zilla::App::Command::clean;
-BEGIN {
-  $Dist::Zilla::App::Command::clean::VERSION = '4.101900';
+{
+  $Dist::Zilla::App::Command::clean::VERSION = '4.300006';
 }
 # ABSTRACT: clean up after build, test, or install
 use Dist::Zilla::App -command;
 
-use File::Find::Rule;
-
 
 sub abstract { 'clean up after build, test, or install' }
 
@@ -29,7 +27,7 @@ Dist::Zilla::App::Command::clean - clean up after build, test, or install
 
 =head1 VERSION
 
-version 4.101900
+version 4.300006
 
 =head1 SYNOPSIS
 
@@ -46,7 +44,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
