@@ -1,16 +1,14 @@
 use strict;
 use warnings;
 package Dist::Zilla::App::Command::listdeps;
-BEGIN {
-  $Dist::Zilla::App::Command::listdeps::VERSION = '4.200009';
+{
+  $Dist::Zilla::App::Command::listdeps::VERSION = '4.300006';
 }
 use Dist::Zilla::App -command;
 # ABSTRACT: print your distribution's prerequisites
 
 
-use Moose::Autobox;
 use Try::Tiny;
-use Version::Requirements;
 
 sub abstract { "print your distribution's prerequisites" }
 
@@ -22,13 +20,14 @@ sub opt_spec {
 sub extract_dependencies {
   my ($self, $zilla, $phases, $missing) = @_;
 
-  $_->before_build for $zilla->plugins_with(-BeforeBuild)->flatten;
-  $_->gather_files for $zilla->plugins_with(-FileGatherer)->flatten;
-  $_->prune_files  for $zilla->plugins_with(-FilePruner)->flatten;
-  $_->munge_files  for $zilla->plugins_with(-FileMunger)->flatten;
-  $_->register_prereqs for $zilla->plugins_with(-PrereqSource)->flatten;
+  $_->before_build for @{ $zilla->plugins_with(-BeforeBuild) };
+  $_->gather_files for @{ $zilla->plugins_with(-FileGatherer) };
+  $_->prune_files  for @{ $zilla->plugins_with(-FilePruner) };
+  $_->munge_files  for @{ $zilla->plugins_with(-FileMunger) };
+  $_->register_prereqs for @{ $zilla->plugins_with(-PrereqSource) };
 
-  my $req = Version::Requirements->new;
+  require CPAN::Meta::Requirements;
+  my $req = CPAN::Meta::Requirements->new;
   my $prereqs = $zilla->prereqs;
 
   for my $phase (@$phases) {
@@ -36,11 +35,23 @@ sub extract_dependencies {
     $req->add_requirements( $prereqs->requirements_for($phase, 'recommends') );
   }
 
+  require Class::Load;
+
   my @required = grep { $_ ne 'perl' } $req->required_modules;
   if ($missing) {
-    @required = grep { !( try { Class::MOP::load_class($_); 1 }
-                       && $req->accepts_module($_ => $_->VERSION) ) }
-                     @required;
+    my $is_required = sub {
+      my $mod = shift;
+      # it is required if it's not already installed
+      return 1 unless Class::Load::try_load_class($mod);
+      # it is required if the version can't be parsed
+      # right now $_->VERSION by itself will die if the version can't
+      # be parsed, but this may change in the future to only die in that
+      # way if an arg is passed
+      return 1 if ! try { $mod->VERSION(0); 1 };
+      # it is required if the version doesn't meet the requirement
+      return !$req->accepts_module($mod => $mod->VERSION);
+    };
+    @required = grep { $is_required->($_) } @required;
   }
 
   return sort { lc $a cmp lc $b } @required;
@@ -69,7 +80,7 @@ Dist::Zilla::App::Command::listdeps - print your distribution's prerequisites
 
 =head1 VERSION
 
-version 4.200009
+version 4.300006
 
 =head1 SYNOPSIS
 
