@@ -1,6 +1,6 @@
 package Dist::Zilla::Dist::Builder;
-BEGIN {
-  $Dist::Zilla::Dist::Builder::VERSION = '4.200009';
+{
+  $Dist::Zilla::Dist::Builder::VERSION = '4.300006';
 }
 # ABSTRACT: dist zilla subclass for building dists
 use Moose 0.92; # role composition fixes
@@ -131,7 +131,7 @@ sub _setup_default_plugins {
 
     $self->plugins->push($plugin);
   }
-  
+
   unless ($self->plugin_named(':MainModule')) {
     require Dist::Zilla::Plugin::FinderCode;
     my $plugin = Dist::Zilla::Plugin::FinderCode->new({
@@ -145,7 +145,7 @@ sub _setup_default_plugins {
         return;
       },
     });
-    
+
     $self->plugins->push($plugin);
   }
 }
@@ -316,36 +316,43 @@ sub ensure_built_in {
 }
 
 
+sub dist_basename {
+  my ($self) = @_;
+  return join(q{},
+    $self->name,
+    '-',
+    $self->version,
+  );
+}
+
+
+sub archive_filename {
+  my ($self) = @_;
+  return join(q{},
+    $self->dist_basename,
+    ( $self->is_trial ? '-TRIAL' : '' ),
+    '.tar.gz'
+  );
+}
+
+
 sub build_archive {
   my ($self) = @_;
 
   my $built_in = $self->ensure_built;
 
-  my $archive = Archive::Tar->new;
-
-  my $basename = file(join(q{},
-    $self->name,
-    '-',
-    $self->version,
-    ($self->is_trial ? '-TRIAL' : ''),
-  ));
+  my $basename = $self->dist_basename;
+  my $basedir = dir($basename);
 
   $_->before_archive for $self->plugins_with(-BeforeArchive)->flatten;
 
-  my %seen_dir;
-  for my $distfile (sort { length($a->name) <=> length($b->name) } $self->files->flatten) {
-    my $in = file($distfile->name)->dir;
-    $archive->add_files( $built_in->subdir($in) ) unless $seen_dir{ $in }++;
-    $archive->add_files( $built_in->file( $distfile->name ) );
-  }
+  my $method = Class::Load::load_optional_class('Archive::Tar::Wrapper')
+             ? '_build_archive_with_wrapper'
+             : '_build_archive';
 
-  # Fix up the CHMOD on the archived files, to inhibit 'withoutworldwritables'
-  # behaviour on win32.
-  for my $f ( $archive->get_files ) {
-    $f->mode( $f->mode & ~022 );
-  }
+  my $archive = $self->$method($built_in, $basename, $basedir);
 
-  my $file = file("$basename.tar.gz");
+  my $file = file($self->archive_filename);
 
   $self->log("writing archive to $file");
   $archive->write("$file", 9);
@@ -353,11 +360,70 @@ sub build_archive {
   return $file;
 }
 
+sub _build_archive {
+  my ($self, $built_in, $basename, $basedir) = @_;
+
+  $self->log("building archive with Archive::Tar; install Archive::Tar::Wrapper for improved speed");
+
+  my $archive = Archive::Tar->new;
+  my %seen_dir;
+  for my $distfile (
+    sort { length($a->name) <=> length($b->name) } $self->files->flatten
+  ) {
+    my $in = file($distfile->name)->dir;
+
+    unless ($seen_dir{ $in }++) {
+      $archive->add_data(
+        $basedir->subdir($in),
+        '',
+        { type => Archive::Tar::Constant::DIR(), mode => 0755 },
+      )
+    }
+
+    my $filename = $built_in->file( $distfile->name );
+    my $content = do {
+      use autodie;
+      local $/;
+      open my $fh, '<', $filename;
+      <$fh>;
+    };
+    $archive->add_data(
+      $basedir->file( $distfile->name ),
+      $content,
+      { mode => (stat $filename)[2] & ~022 },
+    );
+  }
+
+  return $archive;
+}
+
+sub _build_archive_with_wrapper {
+  my ($self, $built_in, $basename, $basedir) = @_;
+
+  $self->log("building archive with Archive::Tar::Wrapper");
+
+  my $archive = Archive::Tar::Wrapper->new;
+
+  for my $distfile (
+    sort { length($a->name) <=> length($b->name) } $self->files->flatten
+  ) {
+    my $in = file($distfile->name)->dir;
+
+    my $filename = $built_in->file( $distfile->name );
+    $archive->add(
+      $basedir->file( $distfile->name )->stringify,
+      $filename->stringify,
+      { perm => (stat $filename)[2] & ~022 },
+    );
+  }
+
+  return $archive;
+}
+
 sub _prep_build_root {
   my ($self, $build_root) = @_;
 
-  my $default_name = $self->name . q{-} . $self->version;
-  $build_root = dir($build_root || $default_name);
+  $build_root = dir($build_root || $self->dist_basename);
 
   $build_root->mkpath unless -d $build_root;
 
@@ -531,7 +597,7 @@ Dist::Zilla::Dist::Builder - dist zilla subclass for building dists
 
 =head1 VERSION
 
-version 4.200009
+version 4.300006
 
 =head1 ATTRIBUTES
 
@@ -583,6 +649,22 @@ This method just calls C<ensure_built_in> with no arguments.  It gets you the
 default behavior without the weird-looking formulation of C<ensure_built_in>
 with no object for the preposition!
 
+=head2 dist_basename
+
+  my $basename = $zilla->dist_basename;
+
+This method will return the dist's basename (e.g. C<Dist-Name-1.01>.
+The basename is used as the top-level directory in the tarball.  It
+does not include C<-TRIAL>, even if building a trial dist.
+
+=head2 archive_filename
+
+  my $tarball = $zilla->archive_filename;
+
+This method will return the filename (e.g. C<Dist-Name-1.01.tar.gz>)
+of the tarball of this dist.  It will include C<-TRIAL> if building a
+trial dist.  The tarball might not exist.
+
 =head2 build_archive
 
   $zilla->build_archive;
