@@ -1,10 +1,12 @@
 package Dist::Zilla::File::OnDisk;
-BEGIN {
-  $Dist::Zilla::File::OnDisk::VERSION = '4.200009';
+{
+  $Dist::Zilla::File::OnDisk::VERSION = '4.300006';
 }
 # ABSTRACT: a file that comes from your filesystem
 use Moose;
 
+use namespace::autoclean;
+
 
 has content => (
   is  => 'rw',
@@ -41,7 +43,6 @@ sub _read_file {
 with 'Dist::Zilla::Role::File';
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -53,7 +54,7 @@ Dist::Zilla::File::OnDisk - a file that comes from your filesystem
 
 =head1 VERSION
 
-version 4.200009
+version 4.300006
 
 =head1 DESCRIPTION
 
