@@ -1,11 +1,13 @@
 package Dist::Zilla::MVP::Assembler::GlobalConfig;
-BEGIN {
-  $Dist::Zilla::MVP::Assembler::GlobalConfig::VERSION = '4.200000';
+{
+  $Dist::Zilla::MVP::Assembler::GlobalConfig::VERSION = '4.300006';
 }
 use Moose;
 extends 'Dist::Zilla::MVP::Assembler';
 # ABSTRACT: Dist::Zilla::MVP::Assembler for global configuration
 
+use namespace::autoclean;
+
 
 has stash_registry => (
   is  => 'ro',
@@ -25,7 +27,7 @@ sub register_stash {
   return;
 }
 
-no Moose;
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -37,7 +39,7 @@ Dist::Zilla::MVP::Assembler::GlobalConfig - Dist::Zilla::MVP::Assembler for glob
 
 =head1 VERSION
 
-version 4.200000
+version 4.300006
 
 =head1 OVERVIEW
 
@@ -64,7 +66,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
