@@ -1,11 +1,13 @@
 package Dist::Zilla::MVP::RootSection;
-BEGIN {
-  $Dist::Zilla::MVP::RootSection::VERSION = '4.200000';
+{
+  $Dist::Zilla::MVP::RootSection::VERSION = '4.300006';
 }
 use Moose;
 extends 'Config::MVP::Section';
 # ABSTRACT: a standard section in Dist::Zilla's configuration sequence
 
+use namespace::autoclean;
+
 
 use MooseX::LazyRequire;
 use MooseX::SetOnce;
@@ -35,6 +37,7 @@ after finalize => sub {
   $self->set_zilla($zilla);
 };
 
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -46,7 +49,7 @@ Dist::Zilla::MVP::RootSection - a standard section in Dist::Zilla's configuratio
 
 =head1 VERSION
 
-version 4.200000
+version 4.300006
 
 =head1 DESCRIPTION
 
@@ -79,7 +82,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
