@@ -1,12 +1,16 @@
 package Dist::Zilla::Plugin::MakeMaker::Runner;
-BEGIN {
-  $Dist::Zilla::Plugin::MakeMaker::Runner::VERSION = '4.200000';
+{
+  $Dist::Zilla::Plugin::MakeMaker::Runner::VERSION = '4.300006';
 }
 # ABSTRACT: Test and build dists with a Makefile.PL
 
 use Moose;
-with 'Dist::Zilla::Role::BuildRunner';
-with 'Dist::Zilla::Role::TestRunner';
+with(
+  'Dist::Zilla::Role::BuildRunner',
+  'Dist::Zilla::Role::TestRunner',
+);
+
+use namespace::autoclean;
 
 use Config;
 
@@ -31,11 +35,14 @@ sub test {
 
   my $make = $self->make_path;
   $self->build;
-  system($make, 'test') and die "error running $make test\n";
+  system($make, 'test',
+    ( $self->zilla->logger->get_debug ? 'TEST_VERBOSE=1' : () ),
+  ) and die "error running $make test\n";
 
   return;
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -47,7 +54,7 @@ Dist::Zilla::Plugin::MakeMaker::Runner - Test and build dists with a Makefile.PL
 
 =head1 VERSION
 
-version 4.200000
+version 4.300006
 
 =head1 AUTHOR
 
@@ -55,7 +62,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
