@@ -1,10 +1,12 @@
 package Dist::Zilla::Plugin::ShareDir;
-BEGIN {
-  $Dist::Zilla::Plugin::ShareDir::VERSION = '4.200000';
+{
+  $Dist::Zilla::Plugin::ShareDir::VERSION = '4.300006';
 }
 # ABSTRACT: install a directory's contents as "ShareDir" content
 use Moose;
 
+use namespace::autoclean;
+
 use Moose::Autobox;
 
 
@@ -31,7 +33,6 @@ sub share_dir_map {
 
 with 'Dist::Zilla::Role::ShareDir';
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -43,13 +44,16 @@ Dist::Zilla::Plugin::ShareDir - install a directory's contents as "ShareDir" con
 
 =head1 VERSION
 
-version 4.200000
+version 4.300006
 
 =head1 SYNOPSIS
 
 In your F<dist.ini>:
 
   [ShareDir]
+  dir = share
+
+  If no C<dir> is provided, the default is F<share>.
 
 =head1 AUTHOR
 
@@ -57,7 +61,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
