@@ -1,11 +1,13 @@
 package Dist::Zilla::PluginBundle::Basic;
-BEGIN {
-  $Dist::Zilla::PluginBundle::Basic::VERSION = '4.101612';
+{
+  $Dist::Zilla::PluginBundle::Basic::VERSION = '4.300006';
 }
 # ABSTRACT: the basic plugins to maintain and release CPAN dists
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
+use namespace::autoclean;
+
 sub configure {
   my ($self) = @_;
 
@@ -30,7 +32,6 @@ sub configure {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 
@@ -42,7 +43,7 @@ Dist::Zilla::PluginBundle::Basic - the basic plugins to maintain and release CPA
 
 =head1 VERSION
 
-version 4.101612
+version 4.300006
 
 =head1 DESCRIPTION
 
@@ -114,11 +115,11 @@ L<Dist::Zilla::Plugin::UploadToCPAN>
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
