@@ -1,15 +1,16 @@
 package Dist::Zilla::Role::PrereqSource;
-BEGIN {
-  $Dist::Zilla::Role::PrereqSource::VERSION = '4.200009';
+{
+  $Dist::Zilla::Role::PrereqSource::VERSION = '4.300006';
 }
 # ABSTRACT: something that registers prerequisites
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
+use namespace::autoclean;
+
 
 requires 'register_prereqs';
 
-no Moose::Role;
 1;
 
 __END__
@@ -21,7 +22,7 @@ Dist::Zilla::Role::PrereqSource - something that registers prerequisites
 
 =head1 VERSION
 
-version 4.200009
+version 4.300006
 
 =head1 DESCRIPTION
 
