@@ -1,10 +1,12 @@
 package Dist::Zilla::Stash::PAUSE;
-BEGIN {
-  $Dist::Zilla::Stash::PAUSE::VERSION = '4.200009';
+{
+  $Dist::Zilla::Stash::PAUSE::VERSION = '4.300006';
 }
 use Moose;
 # ABSTRACT: a stash of your PAUSE credentials
 
+use namespace::autoclean;
+
 
 sub mvp_aliases {
   return { user => 'username' };
@@ -23,6 +25,7 @@ has password => (
 );
 
 with 'Dist::Zilla::Role::Stash::Login';
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -34,7 +37,7 @@ Dist::Zilla::Stash::PAUSE - a stash of your PAUSE credentials
 
 =head1 VERSION
 
-version 4.200009
+version 4.300006
 
 =head1 OVERVIEW
 
